==> r2r-3.3.18-py3-none-any.whl: shared/abstractions/__init__.py <==
from .base import AsyncSyncMeta, R2RSerializable, syncable
from .document import (
    Document,
    DocumentChunk,
    DocumentResponse,
    DocumentType,
    IngestionMode,
    IngestionStatus,
    KGEnrichmentStatus,
    KGExtractionStatus,
    RawChunk,
    UnprocessedChunk,
)
from .embedding import EmbeddingPurpose, default_embedding_prefixes
from .exception import (
    PDFParsingError,
    PopperNotFoundError,
    R2RDocumentProcessingError,
    R2RException,
)
from .graph import Community, Entity, KGExtraction, Relationship
from .kg import (
    GraphBuildSettings,
    GraphCommunitySettings,
    GraphEntitySettings,
    GraphRelationshipSettings,
    KGCreationSettings,
    KGEnrichmentSettings,
    KGEntityDeduplicationSettings,
    KGRunType,
)
from .llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    MessageType,
    RAGCompletion,
)
from .prompt import Prompt
from .search import (
    AggregateSearchResult,
    ChunkSearchResult,
    ChunkSearchSettings,
    GraphSearchResult,
    GraphSearchSettings,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGGlobalResult,
    KGRelationshipResult,
    KGSearchResultType,
    SearchMode,
    SearchSettings,
    select_search_filters,
)
from .user import Token, TokenData, User
from .vector import (
    IndexArgsHNSW,
    IndexArgsIVFFlat,
    IndexMeasure,
    IndexMethod,
    StorageResult,
    Vector,
    VectorEntry,
    VectorQuantizationType,
    VectorTableName,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "MessageType",
    # Document abstractions
    "Document",
    "DocumentChunk",
    "DocumentResponse",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    "RawChunk",
    "UnprocessedChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    "PDFParsingError",
    "PopperNotFoundError",
    # Graph abstractions
    "Entity",
    "Community",
    "Community",
    "KGExtraction",
    "Relationship",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "GraphSearchResult",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "KGGlobalResult",
    "GraphSearchSettings",
    "ChunkSearchSettings",
    "ChunkSearchResult",
    "SearchSettings",
    "select_search_filters",
    "HybridSearchSettings",
    "SearchMode",
    # KG abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "KGExtraction",
    "KGRunType",
    "GraphEntitySettings",
    "GraphRelationshipSettings",
    "GraphCommunitySettings",
    # User abstractions
    "Token",
    "TokenData",
    "User",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "IndexMethod",
    "IndexMeasure",
    "IndexArgsIVFFlat",
    "IndexArgsHNSW",
    "VectorTableName",
    "VectorQuantizationType",
    "StorageResult",
]

==> r2r-3.3.22-py3-none-any.whl: shared/abstractions/__init__.py <==
from .base import AsyncSyncMeta, R2RSerializable, syncable
from .document import (
    Document,
    DocumentChunk,
    DocumentResponse,
    DocumentType,
    IngestionMode,
    IngestionStatus,
    KGEnrichmentStatus,
    KGExtractionStatus,
    RawChunk,
    UnprocessedChunk,
)
from .embedding import EmbeddingPurpose, default_embedding_prefixes
from .exception import (
    PDFParsingError,
    PopperNotFoundError,
    R2RDocumentProcessingError,
    R2RException,
)
from .graph import Community, Entity, KGExtraction, Relationship, StoreType
from .kg import (
    GraphCommunitySettings,
    KGCreationSettings,
    KGEnrichmentSettings,
    KGRunType,
)
from .llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    MessageType,
    RAGCompletion,
)
from .prompt import Prompt
from .search import (
    AggregateSearchResult,
    ChunkSearchResult,
    ChunkSearchSettings,
    GraphSearchResult,
    GraphSearchSettings,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGRelationshipResult,
    KGSearchResultType,
    SearchMode,
    SearchSettings,
    select_search_filters,
)
from .user import Token, TokenData, User
from .vector import (
    IndexArgsHNSW,
    IndexArgsIVFFlat,
    IndexMeasure,
    IndexMethod,
    StorageResult,
    Vector,
    VectorEntry,
    VectorQuantizationType,
    VectorTableName,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "MessageType",
    # Document abstractions
    "Document",
    "DocumentChunk",
    "DocumentResponse",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    "RawChunk",
    "UnprocessedChunk",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    "PDFParsingError",
    "PopperNotFoundError",
    # Graph abstractions
    "Entity",
    "Community",
    "Community",
    "KGExtraction",
    "Relationship",
    "StoreType",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "GraphSearchResult",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "GraphSearchSettings",
    "ChunkSearchSettings",
    "ChunkSearchResult",
    "SearchSettings",
    "select_search_filters",
    "HybridSearchSettings",
    "SearchMode",
    # KG abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "KGExtraction",
    "KGRunType",
    "GraphCommunitySettings",
    # User abstractions
    "Token",
    "TokenData",
    "User",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "IndexMethod",
    "IndexMeasure",
    "IndexArgsIVFFlat",
    "IndexArgsHNSW",
    "VectorTableName",
    "VectorQuantizationType",
    "StorageResult",
]
